.. include:: links.inc

.. _forking:

===================================
Making Your own Copy (fork) of Iris
===================================

You need to do this only once.  The instructions here are very similar
to the instructions at http://help.github.com/forking/, please see
that page for more detail.  We're repeating some of it here just to give the
specifics for the `Iris`_ project, and to suggest some default names.


Set up and Configure a Github Account
=====================================

If you don't have a github account, go to the github page, and make one.

You then need to configure your account to allow write access, see
the `generating sss keys for GitHub`_ help on `github help`_.


Create Your own Forked Copy of Iris
===================================

#. Log into your github account.
#. Go to the `Iris`_ github home at `Iris github`_.
#. Click on the *fork* button:

   .. image:: forking_button.png

   Now, after a short pause, you should find yourself at the home page for
   your own forked copy of `Iris`_.


